# Set version
from pkg_resources import get_distribution
__version__ = get_distribution('pandasgui').version

# Imports
from qtstylish.qtstylish import dark, light, ThemeSwitcher
from qtstylish.demo_widget import DemoWidget

__all__ = ["dark", "light", "ThemeSwitcher", "DemoWidget", "__version__"]



from qtstylish import DemoWidget, ThemeSwitcher
import sys
from PyQt5 import QtWidgets, QtGui, QtCore
import os

if __name__ == '__main__':
    app = QtWidgets.QApplication(sys.argv)

    dw = DemoWidget()
    dw.setStyle(QtWidgets.QStyleFactory.create("Fusion"))
    ts = ThemeSwitcher(dw, hot_reload=True)

    ts.resize(1000, 700)
    app.exec_()
